/*
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
 distributed with this work for additional information
 regarding copyright ownership.  The ASF licenses this file
 to you under the Apache License, Version 2.0 (the
 "License"); you may not use this file except in compliance
 with the License.  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing,
 software distributed under the License is distributed on an
 "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 */

package org.apache.plc4x.protocols.s7;

import org.junit.Test;
import org.apache.daffodil.tdml.Runner;
import org.junit.AfterClass;

/**
 * Executes all tests for the ISO on TCP / TPKT protocol.
 */
public class ProtocolTest {

  static Runner runner = new Runner("org/apache/plc4x/protocols/s7/", "protocol.tdml");

  @AfterClass
  static public void tearDown() {
    runner.reset();
  }

  @Test public void test_TPKT_tpktPacketContainingCotpConnectResponse() { runner.runOneTest("TPKT-tpktPacketContainingCotpConnectResponse"); }
  @Test public void test_TPKT_invalidMagicByte() { runner.runOneTest("TPKT-invalidMagicByte"); }
  @Test public void test_TPKT_tooShortPayload() { runner.runOneTest("TPKT-tooShortPayload"); }
  @Test public void test_TPKT_tooLongPayload() { runner.runOneTest("TPKT-tooLongPayload"); }
  @Test public void test_COTP_typeConnectionRequest() { runner.runOneTest("COTP-typeConnectionRequest"); }
  @Test public void test_COTP_typeConnectionResponse() { runner.runOneTest("COTP-typeConnectionResponse"); }
  @Test public void test_COTP_typeDisconnectionRequest() { runner.runOneTest("COTP-typeDisconnectionRequest"); }
  @Test public void test_COTP_typeDisconnectionResponse() { runner.runOneTest("COTP-typeDisconnectionResponse"); }
  @Test public void test_COTP_typeError() { runner.runOneTest("COTP-typeError"); }
  @Test public void test_COTP_typeData() { runner.runOneTest("COTP-typeData"); }
  @Test public void test_COTP_typeDataEndOfTransmission() { runner.runOneTest("COTP-typeDataEndOfTransmission"); }
  @Test public void test_COTP_invalidType() { runner.runOneTest("COTP-invalidType"); }
  @Test public void test_COTP_parameterTpduSize() { runner.runOneTest("COTP-parameterTpduSize"); }
  @Test public void test_COTP_parameterCallingTsap() { runner.runOneTest("COTP-parameterCallingTsap"); }
  @Test public void test_COTP_parameterCalledTsap() { runner.runOneTest("COTP-parameterCalledTsap"); }
  @Test public void test_COTP_parameterChecksum() { runner.runOneTest("COTP-parameterChecksum"); }
  @Test public void test_COTP_parameterDisconnectAdditionalInformation() { runner.runOneTest("COTP-parameterDisconnectAdditionalInformation"); }
  @Test public void test_COTP_invalidParameterType() { runner.runOneTest("COTP-invalidParameterType"); }
  @Test public void test_COTP_scenarioConnectionRequest() { runner.runOneTest("COTP-scenarioConnectionRequest"); }
  @Test public void test_COTP_scenarioConnectionResponse() { runner.runOneTest("COTP-scenarioConnectionResponse"); }
  @Test public void test_COTP_scenarioDataTpdu() { runner.runOneTest("COTP-scenarioDataTpdu"); }
  @Test public void test_S7_Setup_Communication_Request() { runner.runOneTest("S7-Setup-Communication-Request"); }
  @Test public void test_S7_SetupCommunicationResponse() { runner.runOneTest("S7-SetupCommunicationResponse"); }
  @Test public void test_S7_ReadSZLCPUFunctionRequest() { runner.runOneTest("S7-ReadSZLCPUFunctionRequest"); }
  @Test public void test_S7_ReadSZLCPUFunctionResponse() { runner.runOneTest("S7-ReadSZLCPUFunctionResponse"); }
  @Test public void test_S7_ReadVarRequestSingleItem() { runner.runOneTest("S7-ReadVarRequestSingleItem"); }
  @Test public void test_S7_ReadVarResponseSingleItem() { runner.runOneTest("S7-ReadVarResponseSingleItem"); }
  @Test public void test_S7_ReadVarRequestMixedItems() { runner.runOneTest("S7-ReadVarRequestMixedItems"); }
  @Test public void test_S7_ReadVarResponseMixedItems() { runner.runOneTest("S7-ReadVarResponseMixedItems"); }
  @Test public void test_S7_ReadVarResponseMixedItemsWithOddNumberOfBytes() { runner.runOneTest("S7-ReadVarResponseMixedItemsWithOddNumberOfBytes"); }
  @Test public void test_S7_ReadVarRequestNoFillingBytes() { runner.runOneTest("S7-ReadVarRequestNoFillingBytes"); }
  @Test public void test_S7_ReadVarResponseNoFillingBytes() { runner.runOneTest("S7-ReadVarResponseNoFillingBytes"); }
  @Test public void test_S7_ReadVarRequestWithFillingBytes() { runner.runOneTest("S7-ReadVarRequestWithFillingBytes"); }
  @Test public void test_S7_ReadVarResponseWithFillingBytes() { runner.runOneTest("S7-ReadVarResponseWithFillingBytes"); }
  @Test public void test_S7_WriteVarRequestSingleItem() { runner.runOneTest("S7-WriteVarRequestSingleItem"); }
  @Test public void test_S7_WriteVarResponseSingleItem() { runner.runOneTest("S7-WriteVarResponseSingleItem"); }
  @Test public void test_S7_ReadVarRequestMultipleItems() { runner.runOneTest("S7-ReadVarRequestMultipleItems"); }
  @Test public void test_S7_ReadVarResponseMultipleItems() { runner.runOneTest("S7-ReadVarResponseMultipleItems"); }
  @Test public void test_S7_WriteVarRequestMultipleItems() { runner.runOneTest("S7-WriteVarRequestMultipleItems"); }
  @Test public void test_S7_WriteVarResponseMultipleItems() { runner.runOneTest("S7-WriteVarResponseMultipleItems"); }
}
